/* Sistemas Integrados TEKNISA
   Compras e Suprimentos

Nome: 8075_CMPSTPO_GERA_SOLICITACAO.sql

Descrio:
Stored procedure para gerao de solicitao de compras a partir dos registros
da tabela de trabalho TRABNECECOMP retornada pela stored procedure
NECESSIDADE_DE_COMPRAS.

P_CDFILILANC - Filial de lanamento (que gerou a solicitao).
P_NRNECECOMP - Nmero sequencial utilizado no clculo.
P_CDOPERLANC - Operador que lanou a solicitao de compras

Criao:
22/01/1999 Leonardo Monteiro.
*/

CREATE OR REPLACE
PROCEDURE SF_GERA_SOLICITACAO(
   P_CDFILILANC IN SOLICITA.CDFILLANCA%TYPE,
   P_NRNECECOMP IN TRABNECECOMP.NRNECECOMP%TYPE,
   P_CDOPERLANC IN SOLICITA.CDOPERLANC%TYPE,
   P_EXTRA      IN VARCHAR2 DEFAULT 'N',
   P_MSGEXTRA   IN VARCHAR2 DEFAULT NULL,
   P_NRORG      IN SOLICITA.NRORG%TYPE DEFAULT 1) IS

   V_PRXSOLICMP     VARCHAR2(20);
   V_CDFILCENT      VARCHAR2(4);
   V_CDFILCENTPME   VARCHAR2(4);
   V_CDFILITIPOCARD VARCHAR2(4);
   V_IDUTAPROVSOL     CHAR(1);
   V_IDFILCENTPME     CHAR(1);
   V_IDSOLIAPROV      CHAR(1);
   V_IDUTILDTPROC     CHAR(1);
   V_IDUTILCONSSOLIOL CHAR(1);
   V_IDPERALTSAPR     CHAR(1);
   V_DTPROCESS    DATE;
BEGIN
   SELECT
      MAX(IDUTILDTPROC)
   INTO
      V_IDUTILDTPROC
   FROM
      PARAMGERAL
   WHERE PARAMGERAL.NRORG = P_NRORG;

   SELECT
      NVL(MAX(IDUTILCONSSOLIOL), 'N')
   INTO
      V_IDUTILCONSSOLIOL
   FROM
      PARASUPRI
   WHERE PARASUPRI.NRORG = P_NRORG
     AND PARASUPRI.CDFILIAL = (SELECT NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)
                               FROM  FILIAL
                               WHERE FILIAL.CDFILIAL = P_CDFILILANC
                                 AND FILIAL.NRORG = P_NRORG);
   FOR CUR_FILIAL IN
      (SELECT DISTINCT
          TRABNECECOMP.CDFILNECECMP
       FROM
          TRABNECECOMP
       WHERE TRABNECECOMP.NRNECECOMP = P_NRNECECOMP
         AND TRABNECECOMP.NRORG = P_NRORG)
   LOOP
      V_IDUTAPROVSOL := '';
      V_PRXSOLICMP   := '';
      V_CDFILCENT    := '';
      V_IDSOLIAPROV  := '';
      V_IDPERALTSAPR := '';
      NOVO_CODIGO('SOLICOMP'||CUR_FILIAL.CDFILNECECMP||P_CDFILILANC, V_PRXSOLICMP, 1, P_NRORG);
      V_PRXSOLICMP := SUBSTR(V_PRXSOLICMP,11,10);
      SELECT
         MAX(IDUTAPROVSOL),
         MAX(SUBSTR(NVL(IDPERALTSAPR, 'NNN'), 3,1))
      INTO
         V_IDUTAPROVSOL,
         V_IDPERALTSAPR
      FROM
         PARCMPSUP
      WHERE PARCMPSUP.CDFILIAL = CUR_FILIAL.CDFILNECECMP
        AND PARCMPSUP.NRORG = P_NRORG;

      IF V_IDUTAPROVSOL = 'S' THEN
         IF V_IDPERALTSAPR = 'S' THEN
            V_IDSOLIAPROV := 'S';
         ELSE
            V_IDSOLIAPROV := 'N';
         END IF;
      ELSE
         V_IDSOLIAPROV := 'S';
      END IF;

      SELECT
         MAX(NVL(FILIAL.CDFILCENTCMP, FILIAL.CDFILIAL)),
         MAX(CDFILCENTPME),
         MAX(IDFILCENTPME)
      INTO
         V_CDFILCENT,
         V_CDFILCENTPME,
         V_IDFILCENTPME
      FROM
         FILIAL
      WHERE FILIAL.CDFILIAL = CUR_FILIAL.CDFILNECECMP
        AND FILIAL.NRORG = P_NRORG;

      INSERT INTO SOLICITA
        (CDFILSOLI,
         CDFILLANCA,
         NRSOLICMP,
         DTSOLCMP,
         IDTIPLAN,
         CDFILCENT,
         CDOPERLANC,
         NRNECECMPSOL,
         IDSOLEXTRA,
         NRORG)
      VALUES
        (CUR_FILIAL.CDFILNECECMP,
         P_CDFILILANC,
         V_PRXSOLICMP,
         TO_DATE(SYSDATE),
         'A',
         V_CDFILCENT,
         P_CDOPERLANC,
         P_NRNECECOMP,
         P_EXTRA,
         P_NRORG);

      IF P_EXTRA = 'S' THEN
         INSERT INTO MOVSOLEXT
            (CDFILSOLEXT,
             CDFILLANCEXT,
             NRSOLIMOVEXT,
             DTMOVSOLEXT,
             CDOPERADOR,
             DSJUSTSOLEXT,
             NRORG)
         VALUES
            (CUR_FILIAL.CDFILNECECMP,
             P_CDFILILANC,
             V_PRXSOLICMP,
             SYSDATE,
             P_CDOPERLANC,
             P_MSGEXTRA,
             P_NRORG);
      END IF;

      IF (V_CDFILCENTPME IS NOT NULL) AND (NVL(V_IDFILCENTPME, 'N') = 'N') THEN
         SELECT
            MAX(CDFILIAL)
         INTO
            V_CDFILITIPOCARD
         FROM
            FILITIPOCARD
         WHERE CDFILCENTPME = V_CDFILCENTPME
           AND CDFILIAL     =  CUR_FILIAL.CDFILNECECMP
           AND NRORG        = P_NRORG;

         IF (V_CDFILITIPOCARD IS NOT NULL) THEN
            V_IDSOLIAPROV := 'N';
         END IF;
      END IF;

      IF V_IDUTILCONSSOLIOL = 'S' THEN
         INSERT INTO ITEMSOLI
           (CDFILSOLI,
            CDFILLAN,
            NRSOLICMP,
            CDPRODUTO,
            DTPROGENTR,
            DTUTILIZA,
            QTSOLIPROD,
            IDSOLIAPROV,
            CDFILIOPELOG,
            NRORG)
         SELECT
            CUR_FILIAL.CDFILNECECMP,
            P_CDFILILANC,
            V_PRXSOLICMP,
            CDPRODNECCMP,
            DTENTRNECCMP,
            DTPRIUTIPROD,
            QTPRCNVCOMPR,
            V_IDSOLIAPROV,
            (SELECT
                MAX(P.CDFILIOPELOG)
             FROM
                PARAMPRODSUP P
             WHERE
                P.CDFILIAL     = CUR_FILIAL.CDFILNECECMP AND
                P.CDPRODUTO    = CDPRODNECCMP            AND
                P.NRORG        = P_NRORG                 AND
                P.CDFILIOPELOG IS NOT NULL
             ),
             P_NRORG
         FROM
            TRABNECECOMP
         WHERE
            (NRNECECOMP   = P_NRNECECOMP)            AND
            (IDMARCNECCMP = 'S')                     AND
            (CDFILNECECMP = CUR_FILIAL.CDFILNECECMP) AND
            (NRORG        = P_NRORG);
      ELSE
         INSERT INTO ITEMSOLI
           (CDFILSOLI,
            CDFILLAN,
            NRSOLICMP,
            CDPRODUTO,
            DTPROGENTR,
            DTUTILIZA,
            QTSOLIPROD,
            IDSOLIAPROV,
            NRORG)
         SELECT
            CUR_FILIAL.CDFILNECECMP,
            P_CDFILILANC,
            V_PRXSOLICMP,
            CDPRODNECCMP,
            DTENTRNECCMP,
            DTPRIUTIPROD,
            QTPRCNVCOMPR,
            V_IDSOLIAPROV,
            P_NRORG
         FROM
            TRABNECECOMP
         WHERE
            (NRNECECOMP   = P_NRNECECOMP)            AND
            (IDMARCNECCMP = 'S')                     AND
            (CDFILNECECMP = CUR_FILIAL.CDFILNECECMP) AND
            (NRORG        = P_NRORG);
      END IF;

      IF V_IDUTILDTPROC <> 'S' THEN
         V_DTPROCESS := TRUNC(SYSDATE);
      ELSE
         SELECT
            NVL(MAX(DTPROCESSA), TRUNC(SYSDATE))
         INTO
            V_DTPROCESS
         FROM
            PARAMFILIAL
         WHERE CDFILIAL = CUR_FILIAL.CDFILNECECMP
           AND NRORG    = P_NRORG;
      END IF;

      FOR C_FILINECE IN
         (SELECT
             IT.ROWID
          FROM
             PRODUTO PR,
             ITEMSOLI IT,
             FILIAL,
             FILINECE FI,
             LOGNECECOMP LOG
          WHERE
             LOG.CDFILIAL             = CUR_FILIAL.CDFILNECECMP         AND
             LOG.NRNECECMPLOG         = P_NRNECECOMP                    AND
             FI.CDFILIAL              = LOG.CDFILIAL                    AND
             FI.IDSOLIPREV           <> 'P'                             AND
             FI.CDFILIAL              = FILIAL.CDFILIAL                 AND
             NVL(FILIAL.IDFILCENTPME, 'N') = 'N'                        AND
             FI.CDFILINECCMP          = IT.CDFILSOLI                    AND
             IT.CDPRODUTO             = PR.CDPRODUTO                    AND
             IT.DTPROGENTR           >= V_DTPROCESS                     AND
             PR.CDARVPROD BETWEEN LOG.CDPRODINICNC AND LOG.CDPRODFINANC AND
             PR.NRORG     = P_NRORG                                     AND
             IT.NRORG     = P_NRORG                                     AND
             FILIAL.NRORG = P_NRORG                                     AND
             FI.NRORG     = P_NRORG                                     AND
             LOG.NRORG    = P_NRORG)
      LOOP
         UPDATE ITEMSOLI
         SET IDITMCONS = 'S'
         WHERE ITEMSOLI.ROWID = C_FILINECE.ROWID
           AND ITEMSOLI.NRORG = P_NRORG;
      END LOOP;

      IF (V_CDFILCENTPME IS NULL) AND (V_IDFILCENTPME = 'S') THEN
         FOR CUR_NECECOMP IN
            (SELECT
               TRABNECECOMP.CDFILNECECMP,
               TRABNECECOMP.CDPRODNECCMP,
               PRODUTO.CDPRODESTO,
               TRABNECECOMP.DTENTRNECCMP
            FROM
               PRODUTO,
               TRABNECECOMP
            WHERE
               PRODUTO.CDPRODUTO  = TRABNECECOMP.CDPRODNECCMP AND
               NRNECECOMP         = P_NRNECECOMP              AND
               IDMARCNECCMP       = 'S'                       AND
               CDFILNECECMP       = CUR_FILIAL.CDFILNECECMP   AND
               PRODUTO.NRORG      = P_NRORG                   AND
               TRABNECECOMP.NRORG = P_NRORG
            ORDER BY
               DTENTRNECCMP DESC)
         LOOP
            UPDATE
               ITEMSOLI
            SET
               CDFILSOLCONS = CUR_NECECOMP.CDFILNECECMP,
               CDFILLANCONS = P_CDFILILANC,
               NRSOLCMPCONS = V_PRXSOLICMP,
               CDPRODUTCONS = CUR_NECECOMP.CDPRODNECCMP,
               DTPROGENCONS = CUR_NECECOMP.DTENTRNECCMP,
               IDITMCONS    = 'S'
            WHERE
               (DTPROGENTR, CDPRODUTO, CDFILSOLI, NRORG) IN (SELECT
                                                                IT.DTPROGENTR,
                                                                IT.CDPRODUTO,
                                                                IT.CDFILSOLI,
                                                                P_NRORG
                                                             FROM
                                                                PRODUTO,
                                                                FILIAL,
                                                                ITEMSOLI IT
                                                             WHERE
                                                                IT.CDFILSOLCONS IS NULL                          AND
                                                                NVL(IT.IDITMCONS, 'N')  = 'N'                    AND
                                                                NVL(IT.IDSOLIAPROV, 'S')= 'S'                    AND
                                                                IT.CDPRODUTO         = PRODUTO.CDPRODUTO         AND
                                                                PRODUTO.CDPRODESTO   = CUR_NECECOMP.CDPRODESTO   AND
                                                                FILIAL.CDFILIAL      = IT.CDFILSOLI              AND
                                                                FILIAL.CDFILCENTPME  = CUR_NECECOMP.CDFILNECECMP AND
                                                                IT.DTPROGENTR >= CUR_NECECOMP.DTENTRNECCMP       AND
                                                                PRODUTO.NRORG = P_NRORG                          AND
                                                                FILIAL.NRORG  = P_NRORG                          AND
                                                                IT.NRORG      = P_NRORG                          AND
                                                                NOT EXISTS  (SELECT
                                                                                CMPCENTENDIR.CDFILIAL,
                                                                                CMPCENTENDIR.CDPRODUTO
                                                                             FROM
                                                                                CMPCENTENDIR,
                                                                                PRODUTO PI,
                                                                                PRODUTO PC
                                                                             WHERE
                                                                                CMPCENTENDIR.CDFILIAL  = IT.CDFILSOLI AND
                                                                                CMPCENTENDIR.CDPRODUTO = PC.CDPRODUTO AND
                                                                                IT.CDPRODUTO           = PI.CDPRODUTO AND
                                                                                PI.CDARVPROD LIKE PC.CDARVPROD||'%'   AND
                                                                                CMPCENTENDIR.NRORG     = P_NRORG      AND
                                                                                PI.NRORG               = P_NRORG      AND
                                                                                PC.NRORG               = P_NRORG)
                                                             );
         END LOOP;
      END IF;
      DELETE FROM TRABNECECOMP
      WHERE
         (NRNECECOMP = P_NRNECECOMP)              AND
         (IDMARCNECCMP = 'S')                     AND
         (CDFILNECECMP = CUR_FILIAL.CDFILNECECMP) AND
         (NRORG = P_NRORG);
      COMMIT;
   END LOOP;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('SF_GERA_SOLICITACAO','5.05.022'); END;
/

