/* Sistemas Integrados TECNISA
   Planejamento Alimentao Industrial

Nome: EXPORTA_COMENSAIS
      (7800_PLASTPS.SQL)

Descrio: Realiza a cpia de comensais padro de um servio
           para os cardpios do perodo informado.

Parmetros de entrada:
P_CDFILIAL - Filial
P_CDSERVFILI - Servio
P_DTINICIAL - Data Inicial
P_DTFINAL - Data Final
P_IDINSERIR - Identificador de insert na CARDADIA
P_CDOPERADOR - Operador
P_LDIETA - Lista de dietas (servios hospitalares)

Criao:
Dmaso - abr/2004

*/

IF EXISTS (SELECT * FROM SYSOBJECTS O, SYSUSERS U
                    WHERE
	        O.NAME = 'EXPORTA_COMENSAIS' AND
	        TYPE = 'P'                   AND
	        U.UID = O.UID          	     AND
	        U.NAME = USER)
DROP PROCEDURE EXPORTA_COMENSAIS;
GO

CREATE PROCEDURE EXPORTA_COMENSAIS
    @P_CDFILIAL   VARCHAR(4),
    @P_CDSERVFILI VARCHAR(5),
    @P_DTINICIAL  DATETIME,
    @P_DTFINAL    DATETIME,
    @P_IDINSERIR  VARCHAR(1),
    @P_CDOPERADOR VARCHAR(12),
    @P_LDIETA     VARCHAR(2000),
    @P_JUSTALTCOMENS VARCHAR(200), 
    @P_ACAOALTCOMENS VARCHAR(200)
AS
   DECLARE @V_IDCARDIAUTIL VARCHAR(1);
   DECLARE @V_CONTFERIFILI DOUBLE PRECISION;
   DECLARE @V_CONTFERICARD DOUBLE PRECISION;
   DECLARE @V_DIASEMANA VARCHAR(1);
   DECLARE @V_CONTCARD DOUBLE PRECISION;
   DECLARE @V_NRCARDAPIO VARCHAR(20);
   DECLARE @V_QTCOMESTICAR DOUBLE PRECISION;
   DECLARE @V_QTCLIESTICAR DOUBLE PRECISION;
   DECLARE @V_QTFUNESTICAR DOUBLE PRECISION;
   DECLARE @V_QTDOAESTICAR DOUBLE PRECISION;

   /* VARIVEIS DE CONTROLE DE CURSOR */

   DECLARE @C_SERVICO_IDTIPOSERV   VARCHAR(1);
   DECLARE @C_SERVICO_QTCOMESTISEG DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCOMESTITER DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCOMESTIQUA DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCOMESTIQUI DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCOMESTISEX DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCOMESTISAB DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCOMESTIDOM DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCOMESTIFER DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCLIESTISEG DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCLIESTITER DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCLIESTIQUA DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCLIESTIQUI DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCLIESTISEX DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCLIESTISAB DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCLIESTIDOM DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTCLIESTIFER DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTFUNESTISEG DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTFUNESTITER DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTFUNESTIQUA DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTFUNESTIQUI DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTFUNESTISEX DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTFUNESTISAB DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTFUNESTIDOM DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTFUNESTIFER DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTDOAESTISEG DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTDOAESTITER DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTDOAESTIQUA DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTDOAESTIQUI DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTDOAESTISEX DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTDOAESTISAB DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTDOAESTIDOM DOUBLE PRECISION;
   DECLARE @C_SERVICO_QTDOAESTIFER DOUBLE PRECISION;

   DECLARE @C_PONTOENT_CDFILIAL     VARCHAR(4);   
   DECLARE @C_PONTOENT_CDSERVFILI   VARCHAR(5);   
   DECLARE @C_PONTOENT_CDCLIENTE    VARCHAR(21);   
   DECLARE @C_PONTOENT_CDDESTFILI   VARCHAR(3);  
   DECLARE @C_PONTOENT_QTCOESTCSSEG DOUBLE PRECISION;
   DECLARE @C_PONTOENT_QTCOESTCSTER DOUBLE PRECISION;
   DECLARE @C_PONTOENT_QTCOESTCSQUA DOUBLE PRECISION;
   DECLARE @C_PONTOENT_QTCOESTCSQUI DOUBLE PRECISION;
   DECLARE @C_PONTOENT_QTCOESTCSSEX DOUBLE PRECISION;
   DECLARE @C_PONTOENT_QTCOESTCSSAB DOUBLE PRECISION;
   DECLARE @C_PONTOENT_QTCOESTCSDOM DOUBLE PRECISION;
   DECLARE @C_PONTOENT_QTCOESTCSFER DOUBLE PRECISION;

   DECLARE @V_QTTURNO1  DOUBLE PRECISION;
   DECLARE @V_QTTURNO2  DOUBLE PRECISION;
   DECLARE @V_QTTURNO3  DOUBLE PRECISION;
   DECLARE @V_QTTURNO4  DOUBLE PRECISION;
   DECLARE @V_QTCOESTCS DOUBLE PRECISION;

   DECLARE @C_DATA_DTCARDAPIO      DATETIME;
   DECLARE @C_DATA_DTMES           DATETIME;

   DECLARE @V_CDCONTADOR           VARCHAR(20);

   DECLARE @C_DIETSERV_CDDIETPAD   VARCHAR(4);
   
   DECLARE @V_OLDQTCOMESTICAR DOUBLE PRECISION;
   DECLARE @V_NRJUSTALTERCOMENS INTEGER;		
      
   
BEGIN
   SELECT @V_IDCARDIAUTIL = ISNULL(MAX(IDCARDIAUTIL), 'N')
   FROM PARAMPLANEJA
   WHERE CDFILIAL = @P_CDFILIAL;

   IF @V_IDCARDIAUTIL IS NULL BEGIN
      SET @V_IDCARDIAUTIL = 'N';
   END;

   DECLARE C_SERVICO CURSOR FOR
   SELECT
      IDTIPOSERV,
      ISNULL(QTCOMESTISEG,0) QTCOMESTISEG,
      ISNULL(QTCOMESTITER,0) QTCOMESTITER,
      ISNULL(QTCOMESTIQUA,0) QTCOMESTIQUA,
      ISNULL(QTCOMESTIQUI,0) QTCOMESTIQUI,
      ISNULL(QTCOMESTISEX,0) QTCOMESTISEX,
      ISNULL(QTCOMESTISAB,0) QTCOMESTISAB,
      ISNULL(QTCOMESTIDOM,0) QTCOMESTIDOM,
      ISNULL(QTCOMESTIFER,0) QTCOMESTIFER,
      ISNULL(QTCLIESTISEG,0) QTCLIESTISEG,
      ISNULL(QTCLIESTITER,0) QTCLIESTITER,
      ISNULL(QTCLIESTIQUA,0) QTCLIESTIQUA,
      ISNULL(QTCLIESTIQUI,0) QTCLIESTIQUI,
      ISNULL(QTCLIESTISEX,0) QTCLIESTISEX,
      ISNULL(QTCLIESTISAB,0) QTCLIESTISAB,
      ISNULL(QTCLIESTIDOM,0) QTCLIESTIDOM,
      ISNULL(QTCLIESTIFER,0) QTCLIESTIFER,
      ISNULL(QTFUNESTISEG,0) QTFUNESTISEG,
      ISNULL(QTFUNESTITER,0) QTFUNESTITER,
      ISNULL(QTFUNESTIQUA,0) QTFUNESTIQUA,
      ISNULL(QTFUNESTIQUI,0) QTFUNESTIQUI,
      ISNULL(QTFUNESTISEX,0) QTFUNESTISEX,
      ISNULL(QTFUNESTISAB,0) QTFUNESTISAB,
      ISNULL(QTFUNESTIDOM,0) QTFUNESTIDOM,
      ISNULL(QTFUNESTIFER,0) QTFUNESTIFER,
      ISNULL(QTDOAESTISEG,0) QTDOAESTISEG,
      ISNULL(QTDOAESTITER,0) QTDOAESTITER,
      ISNULL(QTDOAESTIQUA,0) QTDOAESTIQUA,
      ISNULL(QTDOAESTIQUI,0) QTDOAESTIQUI,
      ISNULL(QTDOAESTISEX,0) QTDOAESTISEX,
      ISNULL(QTDOAESTISAB,0) QTDOAESTISAB,
      ISNULL(QTDOAESTIDOM,0) QTDOAESTIDOM,
      ISNULL(QTDOAESTIFER,0) QTDOAESTIFER
   FROM SERVICO
   WHERE
      CDFILIAL = @P_CDFILIAL AND
      CDSERVFILI = @P_CDSERVFILI;
   OPEN C_SERVICO;
   FETCH NEXT FROM C_SERVICO INTO
      @C_SERVICO_IDTIPOSERV,
      @C_SERVICO_QTCOMESTISEG, @C_SERVICO_QTCOMESTITER, @C_SERVICO_QTCOMESTIQUA, @C_SERVICO_QTCOMESTIQUI,
      @C_SERVICO_QTCOMESTISEX, @C_SERVICO_QTCOMESTISAB, @C_SERVICO_QTCOMESTIDOM, @C_SERVICO_QTCOMESTIFER,
      @C_SERVICO_QTCLIESTISEG, @C_SERVICO_QTCLIESTITER, @C_SERVICO_QTCLIESTIQUA, @C_SERVICO_QTCLIESTIQUI,
      @C_SERVICO_QTCLIESTISEX, @C_SERVICO_QTCLIESTISAB, @C_SERVICO_QTCLIESTIDOM, @C_SERVICO_QTCLIESTIFER,
      @C_SERVICO_QTFUNESTISEG, @C_SERVICO_QTFUNESTITER, @C_SERVICO_QTFUNESTIQUA, @C_SERVICO_QTFUNESTIQUI,
      @C_SERVICO_QTFUNESTISEX, @C_SERVICO_QTFUNESTISAB, @C_SERVICO_QTFUNESTIDOM, @C_SERVICO_QTFUNESTIFER,
      @C_SERVICO_QTDOAESTISEG, @C_SERVICO_QTDOAESTITER, @C_SERVICO_QTDOAESTIQUA, @C_SERVICO_QTDOAESTIQUI,
      @C_SERVICO_QTDOAESTISEX, @C_SERVICO_QTDOAESTISAB, @C_SERVICO_QTDOAESTIDOM, @C_SERVICO_QTDOAESTIFER;

   WHILE (@@FETCH_STATUS = 0) BEGIN

      DECLARE C_DATA CURSOR FOR
      SELECT DTDATA,
             DTMES
      FROM DATA
      WHERE
         (DTDATA BETWEEN @P_DTINICIAL AND @P_DTFINAL)
      ORDER BY DTDATA;

      OPEN C_DATA;
      FETCH NEXT FROM C_DATA INTO
         @C_DATA_DTCARDAPIO,
         @C_DATA_DTMES;
      WHILE (@@FETCH_STATUS = 0) BEGIN

         SELECT
            @V_CONTFERIFILI = COUNT(*)
         FROM FERIFILI
         WHERE
            CDFILIAL = @P_CDFILIAL AND
            DTFERIFILI = @C_DATA_DTCARDAPIO;

         SELECT
            @V_CONTFERICARD = COUNT(*)
         FROM FERICARD
         WHERE
            CDFILIAL = @P_CDFILIAL AND
            DTFERICARD = @C_DATA_DTCARDAPIO;

         SET @V_DIASEMANA = CONVERT(VARCHAR,DATEPART(dw,@C_DATA_DTCARDAPIO));

         DECLARE C_TURNOSERV CURSOR FOR
         SELECT SUM(T1),SUM(T2),SUM(T3),SUM(T4)
         FROM
         (SELECT
             ISNULL(CASE @V_DIASEMANA WHEN 2 THEN QTCOMESTTSEG WHEN 3 THEN QTCOMESTTTER WHEN 4 THEN QTCOMESTTQUA WHEN 5 THEN QTCOMESTTQUI WHEN 6 THEN QTCOMESTTSEX WHEN 7 THEN QTCOMESTTSAB WHEN 1 THEN QTCOMESTTDOM WHEN 8 THEN QTCOMESTTFER END, 0) T1,
             0 T2,
             0 T3,
             0 T4
          FROM TURNOSERV
          WHERE
             CDFILIAL = @P_CDFILIAL AND
             CDSERVFILI = @P_CDSERVFILI AND
             CDTURNO = '1'
          UNION
          SELECT
             0 T1,
             ISNULL(CASE @V_DIASEMANA WHEN 2 THEN QTCOMESTTSEG WHEN 3 THEN QTCOMESTTTER WHEN 4 THEN QTCOMESTTQUA WHEN 5 THEN QTCOMESTTQUI WHEN 6 THEN QTCOMESTTSEX WHEN 7 THEN QTCOMESTTSAB WHEN 1 THEN QTCOMESTTDOM WHEN 8 THEN QTCOMESTTFER END, 0) T2,
             0 T3,
             0 T4
          FROM TURNOSERV
          WHERE
             CDFILIAL = @P_CDFILIAL AND
             CDSERVFILI = @P_CDSERVFILI AND
             CDTURNO = '2'
          UNION
          SELECT
             0 T1,
             0 T2,
             ISNULL(CASE @V_DIASEMANA WHEN 2 THEN QTCOMESTTSEG WHEN 3 THEN QTCOMESTTTER WHEN 4 THEN QTCOMESTTQUA WHEN 5 THEN QTCOMESTTQUI WHEN 6 THEN QTCOMESTTSEX WHEN 7 THEN QTCOMESTTSAB WHEN 1 THEN QTCOMESTTDOM WHEN 8 THEN QTCOMESTTFER END, 0) T3,
             0 T4
          FROM TURNOSERV
          WHERE
             CDFILIAL = @P_CDFILIAL AND
             CDSERVFILI = @P_CDSERVFILI AND
             CDTURNO = '3'
          UNION
          SELECT
             0 T1,
             0 T2,
             0 T3,
             ISNULL(CASE @V_DIASEMANA WHEN 2 THEN QTCOMESTTSEG WHEN 3 THEN QTCOMESTTTER WHEN 4 THEN QTCOMESTTQUA WHEN 5 THEN QTCOMESTTQUI WHEN 6 THEN QTCOMESTTSEX WHEN 7 THEN QTCOMESTTSAB WHEN 1 THEN QTCOMESTTDOM WHEN 8 THEN QTCOMESTTFER END, 0) T4
          FROM TURNOSERV
          WHERE
             CDFILIAL = @P_CDFILIAL AND
             CDSERVFILI = @P_CDSERVFILI AND
             CDTURNO = '4'
          ) A;
         OPEN C_TURNOSERV;
         FETCH NEXT FROM C_TURNOSERV INTO
            @V_QTTURNO1,
            @V_QTTURNO2,
            @V_QTTURNO3,
            @V_QTTURNO4
         IF @@FETCH_STATUS <> 0
         BEGIN
            SET @V_QTTURNO1 = 0;
            SET @V_QTTURNO2 = 0;
            SET @V_QTTURNO3 = 0;
            SET @V_QTTURNO4 = 0;
         END;
         CLOSE C_TURNOSERV;
         DEALLOCATE C_TURNOSERV;

         IF (@C_SERVICO_IDTIPOSERV = 'N') BEGIN

            SELECT
               @V_CONTCARD = COUNT(*)
            FROM CARDADIA
            WHERE
               CDFILIAL = @P_CDFILIAL AND
               CDSERVFILI = @P_CDSERVFILI AND
               DTCARDAPIO = @C_DATA_DTCARDAPIO;

            IF (@V_CONTFERIFILI = 0) OR (@V_IDCARDIAUTIL = 'N') BEGIN
               IF (@V_CONTFERICARD = 0) BEGIN
                  IF (@V_DIASEMANA = '1') BEGIN
                     SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTIDOM;
                     SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTIDOM;
                     SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTIDOM;
                     SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTIDOM;
                  END;
                  IF (@V_DIASEMANA = '2') BEGIN
                     SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTISEG;
                     SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTISEG;
                     SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTISEG;
                     SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTISEG;
                  END;
                  IF (@V_DIASEMANA = '3') BEGIN
                     SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTITER;
                     SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTITER;
                     SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTITER;
                     SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTITER;
                  END;
                  IF (@V_DIASEMANA = '4') BEGIN
                     SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTIQUA;
                     SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTIQUA;
                     SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTIQUA;
                     SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTIQUA;
                  END;
                  IF (@V_DIASEMANA = '5') BEGIN
                     SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTIQUI;
                     SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTIQUI;
                     SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTIQUI;
                     SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTIQUI;
                  END;
                  IF (@V_DIASEMANA = '6') BEGIN
                     SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTISEX;
                     SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTISEX;
                     SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTISEX;
                     SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTISEX;
                  END;
                  IF (@V_DIASEMANA = '7') BEGIN
                     SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTISAB;
                     SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTISAB;
                     SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTISAB;
                     SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTISAB;
                  END;
                  IF (@V_QTCOMESTICAR <> 0) BEGIN
                     IF (@V_CONTCARD = 0) BEGIN
                        IF (@P_IDINSERIR = 'S') BEGIN

                           SET @V_NRCARDAPIO = NULL;
                           SET @V_CDCONTADOR = 'CARDAPIO'+@P_CDFILIAL;
                           EXEC NOVO_CODIGO @V_CDCONTADOR, @P_SEQUENCIAL = @V_NRCARDAPIO OUTPUT, @P_QTDE = 1;
                           SET @V_NRCARDAPIO = SUBSTRING(@V_NRCARDAPIO,11,10);

                           INSERT INTO CARDADIA
                           (CDFILIAL,
                            NRCARDAPIO,
                            CDSERVFILI,
                            CDOPERADOR,
                            DTCARDAPIO,
                            QTCOMESTICAR,
                            QTCLIESTICAR,
                            QTFUNESTICAR,
                            QTDOAESTICAR,
                            QTESTITURNO1,
                            QTESTITURNO2,
                            QTESTITURNO3,
                            QTESTITURNO4,
                            DTULTATUACAR,
                            DTMESCARD)
                           VALUES
                           (@P_CDFILIAL,
                            @V_NRCARDAPIO,
                            @P_CDSERVFILI,
                            @P_CDOPERADOR,
                            @C_DATA_DTCARDAPIO,
                            @V_QTCOMESTICAR,
                            @V_QTCLIESTICAR,
                            @V_QTFUNESTICAR,
                            @V_QTDOAESTICAR,
                            @V_QTTURNO1,
                            @V_QTTURNO2,
                            @V_QTTURNO3,
                            @V_QTTURNO4,
                            GETDATE(),
                            @C_DATA_DTMES);

                            DECLARE C_PONTOENT CURSOR FOR
                               SELECT
                                  CDFILIAL,
                                  CDSERVFILI,
                                  CDCLIENTE,
                                  CDDESTFILI,
                                  QTCOESTCSSEG,
                                  QTCOESTCSTER,
                                  QTCOESTCSQUA,
                                  QTCOESTCSQUI,
                                  QTCOESTCSSEX,
                                  QTCOESTCSSAB,
                                  QTCOESTCSDOM
                               FROM
                                  DESTSRVCLI
                               WHERE
                                  CDFILIAL   = @P_CDFILIAL  AND
                                  CDSERVFILI = @P_CDSERVFILI
                               ORDER BY
                                  CDCLIENTE;
                            OPEN C_PONTOENT;
                            FETCH NEXT FROM C_PONTOENT INTO
                               @C_PONTOENT_CDFILIAL,     @C_PONTOENT_CDSERVFILI,   @C_PONTOENT_CDCLIENTE,    @C_PONTOENT_CDDESTFILI,
                               @C_PONTOENT_QTCOESTCSSEG, @C_PONTOENT_QTCOESTCSTER, @C_PONTOENT_QTCOESTCSQUA, @C_PONTOENT_QTCOESTCSQUI,
                               @C_PONTOENT_QTCOESTCSSEX, @C_PONTOENT_QTCOESTCSSAB, @C_PONTOENT_QTCOESTCSDOM;
                            WHILE (@@FETCH_STATUS = 0) BEGIN
                               SET @V_QTCOESTCS = 0;
                               IF (@V_DIASEMANA = '1') BEGIN
                                  SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSDOM;
                               END;
                               IF (@V_DIASEMANA = '2') BEGIN
                                  SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSSEG;
                               END;
                               IF (@V_DIASEMANA = '3') BEGIN
                                  SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSTER;
                               END;
                               IF (@V_DIASEMANA = '4') BEGIN
                                  SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSQUA;
                               END;
                               IF (@V_DIASEMANA = '5') BEGIN
                                  SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSQUI;
                               END;
                               IF (@V_DIASEMANA = '6') BEGIN
                                  SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSSEX;
                               END;
                               IF (@V_DIASEMANA = '7') BEGIN
                                  SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSSAB;
                               END;

                               INSERT INTO CARDACLI
                                  (CDFILIAL, NRCARDAPIO, CDCLIENTE, CDDESTFILI, QTCOMESTICLI)
                               VALUES
                                  (@C_PONTOENT_CDFILIAL, @V_NRCARDAPIO, @C_PONTOENT_CDCLIENTE, @C_PONTOENT_CDDESTFILI, @V_QTCOESTCS);

                               FETCH NEXT FROM C_PONTOENT INTO
                                  @C_PONTOENT_CDFILIAL,     @C_PONTOENT_CDSERVFILI,   @C_PONTOENT_CDCLIENTE,    @C_PONTOENT_CDDESTFILI,
                                  @C_PONTOENT_QTCOESTCSSEG, @C_PONTOENT_QTCOESTCSTER, @C_PONTOENT_QTCOESTCSQUA, @C_PONTOENT_QTCOESTCSQUI,
                                  @C_PONTOENT_QTCOESTCSSEX, @C_PONTOENT_QTCOESTCSSAB, @C_PONTOENT_QTCOESTCSDOM;
                            END;
                            CLOSE C_PONTOENT;
                            DEALLOCATE C_PONTOENT;

                        END;
                     END
                     ELSE BEGIN
                     
                     	IF (@P_JUSTALTCOMENS IS NOT NULL) BEGIN
							SELECT @V_OLDQTCOMESTICAR = QTCOMESTICAR
							  FROM CARDADIA
							 WHERE CDFILIAL = @P_CDFILIAL
							   AND CDSERVFILI = @P_CDSERVFILI
							   AND DTCARDAPIO = @C_DATA_DTCARDAPIO;
					
							EXEC NOVO_CODIGO 'JUSTALTERCOMENS', @P_SEQUENCIAL = @V_NRJUSTALTERCOMENS OUTPUT, @P_QTDE = 1;
								
							INSERT INTO JUSTALTERCOMENS (NRJUSTALTERCOMENS, CDFILIAL, CDSERVFILI, DTCARDAPIO, QTCOMENSTOTOLD, QTCOMENSTOTNEW,
														 DTHRALTERCOMENS, CDOPERADOR, DSJUSTIFICATIVA, DSACAO, IDORIGALTERACAO)
							VALUES (@V_NRJUSTALTERCOMENS, @P_CDFILIAL, @P_CDSERVFILI, @C_DATA_DTCARDAPIO, @V_OLDQTCOMESTICAR, @V_QTCOMESTICAR,
									GETDATE(), @P_CDOPERADOR, @P_JUSTALTCOMENS, @P_ACAOALTCOMENS, 'EXPORTARCOMENS');
						END;					                 

                                             
                        UPDATE CARDADIA
                        SET CDOPERADOR   = @P_CDOPERADOR,
                            DTULTATUACAR = GETDATE(),
                            QTCOMESTICAR = @V_QTCOMESTICAR,
                            QTCLIESTICAR = @V_QTCLIESTICAR,
                            QTFUNESTICAR = @V_QTFUNESTICAR,
                            QTDOAESTICAR = @V_QTDOAESTICAR,
                            QTESTITURNO1 = @V_QTTURNO1,
                            QTESTITURNO2 = @V_QTTURNO2,
                            QTESTITURNO3 = @V_QTTURNO3,
                            QTESTITURNO4 = @V_QTTURNO4
                        WHERE
                            CDFILIAL = @P_CDFILIAL AND
                            CDSERVFILI = @P_CDSERVFILI AND
                            DTCARDAPIO = @C_DATA_DTCARDAPIO;

                        /* DELETA PONTO DE ENTREGA ANTIGO */
                        DELETE FROM CARDACLI
                        WHERE
                           CARDACLI.CDFILIAL = @P_CDFILIAL AND
                           EXISTS (SELECT
                                      C.NRCARDAPIO
                                   FROM
                                      CARDADIA C
                                   WHERE
                                      C.CDSERVFILI  = @P_CDSERVFILI AND
                                      C.DTCARDAPIO  = @C_DATA_DTCARDAPIO AND
                                      CARDACLI.CDFILIAL   = C.CDFILIAL AND
                                      CARDACLI.NRCARDAPIO = C.NRCARDAPIO);
                        /* ================================ */

                        /* INSERE PONTO DE ENTREGA ======== */
                        DECLARE C_PONTOENT CURSOR FOR
                           SELECT
                              CDFILIAL,
                              CDSERVFILI,
                              CDCLIENTE,
                              CDDESTFILI,
                              QTCOESTCSSEG,
                              QTCOESTCSTER,
                              QTCOESTCSQUA,
                              QTCOESTCSQUI,
                              QTCOESTCSSEX,
                              QTCOESTCSSAB,
                              QTCOESTCSDOM
                           FROM
                              DESTSRVCLI
                           WHERE
                              CDFILIAL   = @P_CDFILIAL  AND
                              CDSERVFILI = @P_CDSERVFILI
                           ORDER BY
                              CDCLIENTE;
                        OPEN C_PONTOENT;
                        FETCH NEXT FROM C_PONTOENT INTO
                           @C_PONTOENT_CDFILIAL,     @C_PONTOENT_CDSERVFILI,   @C_PONTOENT_CDCLIENTE,    @C_PONTOENT_CDDESTFILI,
                           @C_PONTOENT_QTCOESTCSSEG, @C_PONTOENT_QTCOESTCSTER, @C_PONTOENT_QTCOESTCSQUA, @C_PONTOENT_QTCOESTCSQUI,
                           @C_PONTOENT_QTCOESTCSSEX, @C_PONTOENT_QTCOESTCSSAB, @C_PONTOENT_QTCOESTCSDOM;
                        WHILE (@@FETCH_STATUS = 0) BEGIN
                           SET @V_QTCOESTCS = 0;
                           IF (@V_DIASEMANA = '1') BEGIN /* DOMINGO */
                              SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSDOM;
                           END;
                           IF (@V_DIASEMANA = '2') BEGIN /* SEGUNDA */
                              SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSSEG;
                           END;
                           IF (@V_DIASEMANA = '3') BEGIN /* TERA */
                              SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSTER;
                           END;
                           IF (@V_DIASEMANA = '4') BEGIN /* QUARTA */
                              SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSQUA;
                           END;
                           IF (@V_DIASEMANA = '5') BEGIN /* QUINTA */
                              SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSQUI;
                           END;
                           IF (@V_DIASEMANA = '6') BEGIN /* SEXTA */
                              SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSSEX;
                           END;
                           IF (@V_DIASEMANA = '7') BEGIN /* SBADO */
                              SET @V_QTCOESTCS = @C_PONTOENT_QTCOESTCSSAB;
                           END;

                           SET @V_NRCARDAPIO = NULL;
                           SELECT
                              @V_NRCARDAPIO = NRCARDAPIO
                           FROM
                              CARDADIA
                           WHERE
                              CDFILIAL   = @P_CDFILIAL   AND
                              CDSERVFILI = @P_CDSERVFILI AND
                              DTCARDAPIO = @C_DATA_DTCARDAPIO;

                           INSERT INTO CARDACLI
                              (CDFILIAL, NRCARDAPIO, CDCLIENTE, CDDESTFILI, QTCOMESTICLI)
                           VALUES
                              (@P_CDFILIAL, @V_NRCARDAPIO, @C_PONTOENT_CDCLIENTE, @C_PONTOENT_CDDESTFILI, @V_QTCOESTCS);

                           FETCH NEXT FROM C_PONTOENT INTO
                              @C_PONTOENT_CDFILIAL,     @C_PONTOENT_CDSERVFILI,   @C_PONTOENT_CDCLIENTE,    @C_PONTOENT_CDDESTFILI,
                              @C_PONTOENT_QTCOESTCSSEG, @C_PONTOENT_QTCOESTCSTER, @C_PONTOENT_QTCOESTCSQUA, @C_PONTOENT_QTCOESTCSQUI,
                              @C_PONTOENT_QTCOESTCSSEX, @C_PONTOENT_QTCOESTCSSAB, @C_PONTOENT_QTCOESTCSDOM;
                        END;
                        CLOSE C_PONTOENT;
                        DEALLOCATE C_PONTOENT;
                        /* ================================ */

                     END;
                  END;
               END
               ELSE BEGIN
                  SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTIFER;
                  SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTIFER;
                  SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTIFER;
                  SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTIFER;

                  IF (@V_QTCOMESTICAR <> 0) BEGIN

                     IF (@V_CONTCARD = 0) BEGIN
                        IF (@P_IDINSERIR = 'S') BEGIN
                           SET @V_NRCARDAPIO = NULL;
                           SET @V_CDCONTADOR = 'CARDAPIO'+@P_CDFILIAL;
                           EXEC NOVO_CODIGO @V_CDCONTADOR, @P_SEQUENCIAL = @V_NRCARDAPIO OUTPUT, @P_QTDE = 1;
                           SET @V_NRCARDAPIO = SUBSTRING(@V_NRCARDAPIO,11,10);

                           INSERT INTO CARDADIA
                           (CDFILIAL,
                            NRCARDAPIO,
                            CDSERVFILI,
                            CDOPERADOR,
                            DTCARDAPIO,
                            QTCOMESTICAR,
                            QTCLIESTICAR,
                            QTFUNESTICAR,
                            QTDOAESTICAR,
                            QTESTITURNO1,
                            QTESTITURNO2,
                            QTESTITURNO3,
                            QTESTITURNO4,
                            DTULTATUACAR,
                            DTMESCARD)
                           VALUES
                           (@P_CDFILIAL,
                            @V_NRCARDAPIO,
                            @P_CDSERVFILI,
                            @P_CDOPERADOR,
                            @C_DATA_DTCARDAPIO,
                            @V_QTCOMESTICAR,
                            @V_QTCLIESTICAR,
                            @V_QTFUNESTICAR,
                            @V_QTDOAESTICAR,
                            @V_QTTURNO1,
                            @V_QTTURNO2,
                            @V_QTTURNO3,
                            @V_QTTURNO4,
                            GETDATE(),
                            @C_DATA_DTMES);

                            DECLARE C_PONTOENT CURSOR FOR
                               SELECT
                                  CDFILIAL,
                                  CDSERVFILI,
                                  CDCLIENTE,
                                  CDDESTFILI,
                                  QTCOESTCSFER
                               FROM
                                  DESTSRVCLI
                               WHERE
                                  CDFILIAL   = @P_CDFILIAL  AND
                                  CDSERVFILI = @P_CDSERVFILI
                               ORDER BY
                                  CDCLIENTE;
                            OPEN C_PONTOENT;
                            FETCH NEXT FROM C_PONTOENT INTO
                               @C_PONTOENT_CDFILIAL, @C_PONTOENT_CDSERVFILI, @C_PONTOENT_CDCLIENTE,
                               @C_PONTOENT_CDDESTFILI, @C_PONTOENT_QTCOESTCSFER;
                            WHILE (@@FETCH_STATUS = 0) BEGIN
                               INSERT INTO CARDACLI
                                  (CDFILIAL, NRCARDAPIO, CDCLIENTE, CDDESTFILI, QTCOMESTICLI)
                               VALUES
                                  (@C_PONTOENT_CDFILIAL, @V_NRCARDAPIO, @C_PONTOENT_CDCLIENTE, @C_PONTOENT_CDDESTFILI, @C_PONTOENT_QTCOESTCSFER);

                               FETCH NEXT FROM C_PONTOENT INTO
                                  @C_PONTOENT_CDFILIAL, @C_PONTOENT_CDSERVFILI, @C_PONTOENT_CDCLIENTE,
                                  @C_PONTOENT_CDDESTFILI, @C_PONTOENT_QTCOESTCSFER;
                            END;
                            CLOSE C_PONTOENT;
                            DEALLOCATE C_PONTOENT;
                        END;
                     END
                     ELSE BEGIN
                        
                     	IF (@P_JUSTALTCOMENS IS NOT NULL) BEGIN
							SELECT @V_OLDQTCOMESTICAR = QTCOMESTICAR
							  FROM CARDADIA
							 WHERE CDFILIAL = @P_CDFILIAL
							   AND CDSERVFILI = @P_CDSERVFILI
							   AND DTCARDAPIO = @C_DATA_DTCARDAPIO;
					
							EXEC NOVO_CODIGO 'JUSTALTERCOMENS', @P_SEQUENCIAL = @V_NRJUSTALTERCOMENS OUTPUT, @P_QTDE = 1;
								
							INSERT INTO JUSTALTERCOMENS (NRJUSTALTERCOMENS, CDFILIAL, CDSERVFILI, DTCARDAPIO, QTCOMENSTOTOLD, QTCOMENSTOTNEW,
														 DTHRALTERCOMENS, CDOPERADOR, DSJUSTIFICATIVA, DSACAO, IDORIGALTERACAO)
							VALUES (@V_NRJUSTALTERCOMENS, @P_CDFILIAL, @P_CDSERVFILI, @C_DATA_DTCARDAPIO, @V_OLDQTCOMESTICAR, @V_QTCOMESTICAR,
									GETDATE(), @P_CDOPERADOR, @P_JUSTALTCOMENS, @P_ACAOALTCOMENS, 'EXPORTARCOMENS');
						END;
                                             
                        UPDATE CARDADIA
                        SET CDOPERADOR   = @P_CDOPERADOR,
                            DTULTATUACAR = GETDATE(),
                            QTCOMESTICAR = @V_QTCOMESTICAR,
                            QTCLIESTICAR = @V_QTCLIESTICAR,
                            QTFUNESTICAR = @V_QTFUNESTICAR,
                            QTDOAESTICAR = @V_QTDOAESTICAR,
                            QTESTITURNO1 = @V_QTTURNO1,
                            QTESTITURNO2 = @V_QTTURNO2,
                            QTESTITURNO3 = @V_QTTURNO3,
                            QTESTITURNO4 = @V_QTTURNO4
                        WHERE
                            CDFILIAL   = @P_CDFILIAL   AND
                            CDSERVFILI = @P_CDSERVFILI AND
                            DTCARDAPIO = @C_DATA_DTCARDAPIO;

                        /* DELETA PONTO DE ENTREGA ANTIGO */
                        DELETE FROM CARDACLI
                        WHERE
                           CARDACLI.CDFILIAL = @P_CDFILIAL AND
                           EXISTS (SELECT
                                      C.NRCARDAPIO
                                   FROM
                                      CARDADIA C
                                   WHERE
                                      C.CDSERVFILI  = @P_CDSERVFILI AND
                                      C.DTCARDAPIO  = @C_DATA_DTCARDAPIO AND
                                      CARDACLI.CDFILIAL   = C.CDFILIAL AND
                                      CARDACLI.NRCARDAPIO = C.NRCARDAPIO);
                        /* ================================ */

                        /* INSERE PONTO DE ENTREGA ======== */
                        DECLARE C_PONTOENT CURSOR FOR
                           SELECT
                              CDFILIAL,
                              CDSERVFILI,
                              CDCLIENTE,
                              CDDESTFILI,
                              QTCOESTCSFER
                           FROM
                              DESTSRVCLI
                           WHERE
                              CDFILIAL   = @P_CDFILIAL  AND
                              CDSERVFILI = @P_CDSERVFILI
                           ORDER BY
                              CDCLIENTE;
                        OPEN C_PONTOENT;
                        FETCH NEXT FROM C_PONTOENT INTO
                           @C_PONTOENT_CDFILIAL, @C_PONTOENT_CDSERVFILI, @C_PONTOENT_CDCLIENTE,
                           @C_PONTOENT_CDDESTFILI, @C_PONTOENT_QTCOESTCSFER;
                        WHILE (@@FETCH_STATUS = 0) BEGIN

                           SET @V_NRCARDAPIO = NULL;
                           SELECT
                              @V_NRCARDAPIO = NRCARDAPIO
                           FROM
                              CARDADIA
                           WHERE
                              CDFILIAL   = @P_CDFILIAL   AND
                              CDSERVFILI = @P_CDSERVFILI AND
                              DTCARDAPIO = @C_DATA_DTCARDAPIO;

                           INSERT INTO CARDACLI
                              (CDFILIAL, NRCARDAPIO, CDCLIENTE, CDDESTFILI, QTCOMESTICLI)
                           VALUES
                              (@P_CDFILIAL, @V_NRCARDAPIO, @C_PONTOENT_CDCLIENTE, @C_PONTOENT_CDDESTFILI, @C_PONTOENT_QTCOESTCSFER);

                           FETCH NEXT FROM C_PONTOENT INTO
                              @C_PONTOENT_CDFILIAL,   @C_PONTOENT_CDSERVFILI,   @C_PONTOENT_CDCLIENTE,
                              @C_PONTOENT_CDDESTFILI, @C_PONTOENT_QTCOESTCSFER;
                        END;
                        CLOSE C_PONTOENT;
                        DEALLOCATE C_PONTOENT;
                       /* ================================ */

                     END;
                  END;
               END;
            END;
         END;
         IF (@C_SERVICO_IDTIPOSERV = 'D') BEGIN

            DECLARE C_DIETSERV CURSOR FOR
            SELECT
               CDDIETPAD,
               ISNULL(QTCOMDIETSEG,0) QTCOMDIETSEG,
               ISNULL(QTCOMDIETTER,0) QTCOMDIETTER,
               ISNULL(QTCOMDIETQUA,0) QTCOMDIETQUA,
               ISNULL(QTCOMDIETQUI,0) QTCOMDIETQUI,
               ISNULL(QTCOMDIETSEX,0) QTCOMDIETSEX,
               ISNULL(QTCOMDIETSAB,0) QTCOMDIETSAB,
               ISNULL(QTCOMDIETDOM,0) QTCOMDIETDOM,
               ISNULL(QTCOMDIETFER,0) QTCOMDIETFER,
               ISNULL(QTCLIDIETSEG,0) QTCLIDIETSEG,
               ISNULL(QTCLIDIETTER,0) QTCLIDIETTER,
               ISNULL(QTCLIDIETQUA,0) QTCLIDIETQUA,
               ISNULL(QTCLIDIETQUI,0) QTCLIDIETQUI,
               ISNULL(QTCLIDIETSEX,0) QTCLIDIETSEX,
               ISNULL(QTCLIDIETSAB,0) QTCLIDIETSAB,
               ISNULL(QTCLIDIETDOM,0) QTCLIDIETDOM,
               ISNULL(QTCLIDIETFER,0) QTCLIDIETFER,
               ISNULL(QTFUNDIETSEG,0) QTFUNDIETSEG,
               ISNULL(QTFUNDIETTER,0) QTFUNDIETTER,
               ISNULL(QTFUNDIETQUA,0) QTFUNDIETQUA,
               ISNULL(QTFUNDIETQUI,0) QTFUNDIETQUI,
               ISNULL(QTFUNDIETSEX,0) QTFUNDIETSEX,
               ISNULL(QTFUNDIETSAB,0) QTFUNDIETSAB,
               ISNULL(QTFUNDIETDOM,0) QTFUNDIETDOM,
               ISNULL(QTFUNDIETFER,0) QTFUNDIETFER,
               ISNULL(QTDOADIETSEG,0) QTDOADIETSEG,
               ISNULL(QTDOADIETTER,0) QTDOADIETTER,
               ISNULL(QTDOADIETQUA,0) QTDOADIETQUA,
               ISNULL(QTDOADIETQUI,0) QTDOADIETQUI,
               ISNULL(QTDOADIETSEX,0) QTDOADIETSEX,
               ISNULL(QTDOADIETSAB,0) QTDOADIETSAB,
               ISNULL(QTDOADIETDOM,0) QTDOADIETDOM,
               ISNULL(QTDOADIETFER,0) QTDOADIETFER
            FROM DIETSERV
            WHERE
               CDFILIAL = @P_CDFILIAL AND
               CDSERVFILI = @P_CDSERVFILI AND
               (CHARINDEX(CDDIETPAD, @P_LDIETA)<>0);
            OPEN C_DIETSERV;

            FETCH NEXT FROM C_DIETSERV INTO
               @C_DIETSERV_CDDIETPAD,
               @C_SERVICO_QTCOMESTISEG, @C_SERVICO_QTCOMESTITER, @C_SERVICO_QTCOMESTIQUA, @C_SERVICO_QTCOMESTIQUI,
               @C_SERVICO_QTCOMESTISEX, @C_SERVICO_QTCOMESTISAB, @C_SERVICO_QTCOMESTIDOM, @C_SERVICO_QTCOMESTIFER,
               @C_SERVICO_QTCLIESTISEG, @C_SERVICO_QTCLIESTITER, @C_SERVICO_QTCLIESTIQUA, @C_SERVICO_QTCLIESTIQUI,
               @C_SERVICO_QTCLIESTISEX, @C_SERVICO_QTCLIESTISAB, @C_SERVICO_QTCLIESTIDOM, @C_SERVICO_QTCLIESTIFER,
               @C_SERVICO_QTFUNESTISEG, @C_SERVICO_QTFUNESTITER, @C_SERVICO_QTFUNESTIQUA, @C_SERVICO_QTFUNESTIQUI,
               @C_SERVICO_QTFUNESTISEX, @C_SERVICO_QTFUNESTISAB, @C_SERVICO_QTFUNESTIDOM, @C_SERVICO_QTFUNESTIFER,
               @C_SERVICO_QTDOAESTISEG, @C_SERVICO_QTDOAESTITER, @C_SERVICO_QTDOAESTIQUA, @C_SERVICO_QTDOAESTIQUI,
               @C_SERVICO_QTDOAESTISEX, @C_SERVICO_QTDOAESTISAB, @C_SERVICO_QTDOAESTIDOM, @C_SERVICO_QTDOAESTIFER;

            WHILE (@@FETCH_STATUS = 0) BEGIN

               SELECT
                  @V_CONTCARD = COUNT(*)
               FROM CARDADIA
               WHERE
                  CDFILIAL   = @P_CDFILIAL AND
                  CDSERVFILI = @P_CDSERVFILI AND
                  DTCARDAPIO = @C_DATA_DTCARDAPIO AND
                  CDDIETPAD  = @C_DIETSERV_CDDIETPAD;

               IF (@V_CONTFERIFILI = 0) OR (@V_IDCARDIAUTIL = 'N') BEGIN
                  IF (@V_CONTFERICARD = 0) BEGIN
                     IF (@V_DIASEMANA = '1') BEGIN
                        SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTIDOM;
                        SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTIDOM;
                        SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTIDOM;
                        SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTIDOM;
                     END;
                     IF (@V_DIASEMANA = '2') BEGIN
                        SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTISEG;
                        SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTISEG;
                        SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTISEG;
                        SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTISEG;
                     END;
                     IF (@V_DIASEMANA = '3') BEGIN
                        SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTITER;
                        SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTITER;
                        SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTITER;
                        SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTITER;
                     END;
                     IF (@V_DIASEMANA = '4') BEGIN
                        SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTIQUA;
                        SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTIQUA;
                        SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTIQUA;
                        SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTIQUA;
                     END;
                     IF (@V_DIASEMANA = '5') BEGIN
                        SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTIQUI;
                        SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTIQUI;
                        SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTIQUI;
                        SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTIQUI;
                     END;
                     IF (@V_DIASEMANA = '6') BEGIN
                        SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTISEX;
                        SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTISEX;
                        SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTISEX;
                        SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTISEX;
                     END;
                     IF (@V_DIASEMANA = '7') BEGIN
                        SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTISAB;
                        SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTISAB;
                        SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTISAB;
                        SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTISAB;
                     END;
                     IF (@V_QTCOMESTICAR = 0) BEGIN
                        IF (@V_CONTCARD = 0) BEGIN
                           IF (@P_IDINSERIR = 'S') BEGIN
                              SET @V_NRCARDAPIO = NULL;
                              SET @V_CDCONTADOR = 'CARDAPIO'+@P_CDFILIAL;
                              EXEC NOVO_CODIGO @V_CDCONTADOR, @P_SEQUENCIAL = @V_NRCARDAPIO OUTPUT, @P_QTDE = 1;
                              SET @V_NRCARDAPIO = SUBSTRING(@V_NRCARDAPIO,11,10);

                              INSERT INTO CARDADIA
                              (CDFILIAL,
                               NRCARDAPIO,
                               CDSERVFILI,
                               CDDIETPAD,
                               CDOPERADOR,
                               DTCARDAPIO,
                               QTCOMESTICAR,
                               QTCLIESTICAR,
                               QTFUNESTICAR,
                               QTDOAESTICAR,
                               QTESTITURNO1,
                               QTESTITURNO2,
                               QTESTITURNO3,
                               QTESTITURNO4,
                               DTULTATUACAR,
                               DTMESCARD)
                              VALUES
                              (@P_CDFILIAL,
                               @V_NRCARDAPIO,
                               @P_CDSERVFILI,
                               @C_DIETSERV_CDDIETPAD,
                               @P_CDOPERADOR,
                               @C_DATA_DTCARDAPIO,
                               @V_QTCOMESTICAR,
                               @V_QTCLIESTICAR,
                               @V_QTFUNESTICAR,
                               @V_QTDOAESTICAR,
                               @V_QTTURNO1,
                               @V_QTTURNO2,
                               @V_QTTURNO3,
                               @V_QTTURNO4,
                               GETDATE(),
                               @C_DATA_DTMES);
                           END;
                        END
                        ELSE BEGIN
                           UPDATE CARDADIA
                           SET CDOPERADOR   = @P_CDOPERADOR,
                               DTULTATUACAR = GETDATE(),
                               QTCOMESTICAR = @V_QTCOMESTICAR,
                               QTCLIESTICAR = @V_QTCLIESTICAR,
                               QTFUNESTICAR = @V_QTFUNESTICAR,
                               QTDOAESTICAR = @V_QTDOAESTICAR,
                               QTESTITURNO1 = @V_QTTURNO1,
                               QTESTITURNO2 = @V_QTTURNO2,
                               QTESTITURNO3 = @V_QTTURNO3,
                               QTESTITURNO4 = @V_QTTURNO4
                           WHERE
                               CDFILIAL   = @P_CDFILIAL        AND
                               CDSERVFILI = @P_CDSERVFILI      AND
                               DTCARDAPIO = @C_DATA_DTCARDAPIO AND
                               CDDIETPAD  = @C_DIETSERV_CDDIETPAD;
                        END;
                     END;
                  END
                  ELSE BEGIN
                     SET @V_QTCOMESTICAR = @C_SERVICO_QTCOMESTIFER;
                     SET @V_QTCLIESTICAR = @C_SERVICO_QTCLIESTIFER;
                     SET @V_QTFUNESTICAR = @C_SERVICO_QTFUNESTIFER;
                     SET @V_QTDOAESTICAR = @C_SERVICO_QTDOAESTIFER;

                     IF (@V_QTCOMESTICAR = 0) BEGIN
                        IF (@V_CONTCARD = 0) BEGIN
                           IF (@P_IDINSERIR = 'S') BEGIN

                              SET @V_NRCARDAPIO = NULL;
                              SET @V_CDCONTADOR = 'CARDAPIO'+@P_CDFILIAL;
                              EXEC NOVO_CODIGO @V_CDCONTADOR, @P_SEQUENCIAL = @V_NRCARDAPIO OUTPUT, @P_QTDE = 1;
                              SET @V_NRCARDAPIO = SUBSTRING(@V_NRCARDAPIO,11,10);

                              INSERT INTO CARDADIA
                              (CDFILIAL,
                               NRCARDAPIO,
                               CDSERVFILI,
                               CDDIETPAD,
                               CDOPERADOR,
                               DTCARDAPIO,
                               QTCOMESTICAR,
                               QTCLIESTICAR,
                               QTFUNESTICAR,
                               QTDOAESTICAR,
                               QTESTITURNO1,
                               QTESTITURNO2,
                               QTESTITURNO3,
                               QTESTITURNO4,
                               DTULTATUACAR,
                               DTMESCARD)
                              VALUES
                              (@P_CDFILIAL,
                               @V_NRCARDAPIO,
                               @P_CDSERVFILI,
                               @C_DIETSERV_CDDIETPAD,
                               @P_CDOPERADOR,
                               @C_DATA_DTCARDAPIO,
                               @V_QTCOMESTICAR,
                               @V_QTCLIESTICAR,
                               @V_QTFUNESTICAR,
                               @V_QTDOAESTICAR,
                               @V_QTTURNO1,
                               @V_QTTURNO2,
                               @V_QTTURNO3,
                               @V_QTTURNO4,
                               GETDATE(),
                               @C_DATA_DTMES);
                           END;
                        END
                        ELSE BEGIN
                           UPDATE CARDADIA
                           SET CDOPERADOR   = @P_CDOPERADOR,
                               DTULTATUACAR = GETDATE(),
                               QTCOMESTICAR = @V_QTCOMESTICAR,
                               QTCLIESTICAR = @V_QTCLIESTICAR,
                               QTFUNESTICAR = @V_QTFUNESTICAR,
                               QTDOAESTICAR = @V_QTDOAESTICAR,
                               QTESTITURNO1 = @V_QTTURNO1,
                               QTESTITURNO2 = @V_QTTURNO2,
                               QTESTITURNO3 = @V_QTTURNO3,
                               QTESTITURNO4 = @V_QTTURNO4
                           WHERE
                               CDFILIAL   = @P_CDFILIAL   AND
                               CDSERVFILI = @P_CDSERVFILI AND
                               DTCARDAPIO = @C_DATA_DTCARDAPIO AND
                               CDDIETPAD  = @C_DIETSERV_CDDIETPAD;
                        END;
                     END;
                  END;
               END;
               FETCH NEXT FROM C_DIETSERV INTO
                  @C_DIETSERV_CDDIETPAD,
                  @C_SERVICO_QTCOMESTISEG, @C_SERVICO_QTCOMESTITER, @C_SERVICO_QTCOMESTIQUA, @C_SERVICO_QTCOMESTIQUI,
                  @C_SERVICO_QTCOMESTISEX, @C_SERVICO_QTCOMESTISAB, @C_SERVICO_QTCOMESTIDOM, @C_SERVICO_QTCOMESTIFER,
                  @C_SERVICO_QTCLIESTISEG, @C_SERVICO_QTCLIESTITER, @C_SERVICO_QTCLIESTIQUA, @C_SERVICO_QTCLIESTIQUI,
                  @C_SERVICO_QTCLIESTISEX, @C_SERVICO_QTCLIESTISAB, @C_SERVICO_QTCLIESTIDOM, @C_SERVICO_QTCLIESTIFER,
                  @C_SERVICO_QTFUNESTISEG, @C_SERVICO_QTFUNESTITER, @C_SERVICO_QTFUNESTIQUA, @C_SERVICO_QTFUNESTIQUI,
                  @C_SERVICO_QTFUNESTISEX, @C_SERVICO_QTFUNESTISAB, @C_SERVICO_QTFUNESTIDOM, @C_SERVICO_QTFUNESTIFER,
                  @C_SERVICO_QTDOAESTISEG, @C_SERVICO_QTDOAESTITER, @C_SERVICO_QTDOAESTIQUA, @C_SERVICO_QTDOAESTIQUI,
                  @C_SERVICO_QTDOAESTISEX, @C_SERVICO_QTDOAESTISAB, @C_SERVICO_QTDOAESTIDOM, @C_SERVICO_QTDOAESTIFER;
            END;
            CLOSE C_DIETSERV;
            DEALLOCATE C_DIETSERV;
         END;
         FETCH NEXT FROM C_DATA INTO
            @C_DATA_DTCARDAPIO,
            @C_DATA_DTMES;
      END;
      CLOSE C_DATA;
      DEALLOCATE C_DATA;

      FETCH NEXT FROM C_SERVICO INTO
         @C_SERVICO_IDTIPOSERV,
         @C_SERVICO_QTCOMESTISEG, @C_SERVICO_QTCOMESTITER, @C_SERVICO_QTCOMESTIQUA, @C_SERVICO_QTCOMESTIQUI,
         @C_SERVICO_QTCOMESTISEX, @C_SERVICO_QTCOMESTISAB, @C_SERVICO_QTCOMESTIDOM, @C_SERVICO_QTCOMESTIFER,
         @C_SERVICO_QTCLIESTISEG, @C_SERVICO_QTCLIESTITER, @C_SERVICO_QTCLIESTIQUA, @C_SERVICO_QTCLIESTIQUI,
         @C_SERVICO_QTCLIESTISEX, @C_SERVICO_QTCLIESTISAB, @C_SERVICO_QTCLIESTIDOM, @C_SERVICO_QTCLIESTIFER,
         @C_SERVICO_QTFUNESTISEG, @C_SERVICO_QTFUNESTITER, @C_SERVICO_QTFUNESTIQUA, @C_SERVICO_QTFUNESTIQUI,
         @C_SERVICO_QTFUNESTISEX, @C_SERVICO_QTFUNESTISAB, @C_SERVICO_QTFUNESTIDOM, @C_SERVICO_QTFUNESTIFER,
         @C_SERVICO_QTDOAESTISEG, @C_SERVICO_QTDOAESTITER, @C_SERVICO_QTDOAESTIQUA, @C_SERVICO_QTDOAESTIQUI,
         @C_SERVICO_QTDOAESTISEX, @C_SERVICO_QTDOAESTISAB, @C_SERVICO_QTDOAESTIDOM, @C_SERVICO_QTDOAESTIFER;

   END;
   CLOSE C_SERVICO;
   DEALLOCATE C_SERVICO;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'EXPORTA_COMENSAIS','5.09.000';
GO

