import {
  Metadata, Http, IDictionary, Router,
} from '@zeedhi/core';
import {
  Col, Text, Textarea, Card, Checkbox, Button,
} from '@zeedhi/common';
import { IterableComponentRender } from '@zeedhi/teknisa-components-common';
import { getRouteParams } from '../router';

export class DetalhamentoTarefaController {
  // Controla a visibilidade dos elementos, referente ao nível de acesso do usuário
  public isDisabledElement = (localStorage.getItem('idpermissstarefas') === 'V');

  public changeButton() {
    const buttonStart = Metadata.getInstance<Col>('colButtonStartTask');
    const buttonPress = Metadata.getInstance<Col>('colButtonPress');
    buttonStart.isVisible = !buttonStart.isVisible;
    buttonPress.isVisible = !buttonPress.isVisible;
  }

  public addTextArea({ component }:{ component:Button }) {
    const buttonBusy = Metadata.getInstance<Button>('buttonBusy');
    const buttonWtAcess = Metadata.getInstance<Button>('buttonWtAcess');
    const buttonCleanPlace = Metadata.getInstance<Button>('buttonCleanPlace');
    const buttonOtherReasons = Metadata.getInstance<Button>('buttonOtherReasons');
    buttonBusy.outline = !(component.label === buttonBusy.label);
    buttonWtAcess.outline = !(component.label === buttonWtAcess.label);
    buttonCleanPlace.outline = !(component.label === buttonCleanPlace.label);
    buttonOtherReasons.outline = !(component.label === buttonOtherReasons.label);
    const textA = Metadata.getInstance<Textarea>('textarea');
    if (component.label === buttonOtherReasons.label) {
      textA.isVisible = true;
    } else {
      textA.isVisible = false;
    }
  }

  public async statusCheck() {
    let chkStatus: boolean = false;
    await Http.post('/statusCheck', { NRFUNCIONARIO: localStorage.getItem('UserLogado') }).then((response: IDictionary) => {
      chkStatus = response.data.dataset.statuschk[0]['COUNT(IDSITUACAOAGEND)'];
    });
    return chkStatus;
  }

  public showDetailsTask() {
    const routeParams = getRouteParams();
    const { nr } = routeParams;
    Http.post('/showDetailsTask', { nr }).then((response: IDictionary) => {
      response.data.dataset.cardDetails.forEach((dados: IDictionary) => {
        const time = dados.DTHORAAGEND.split(' ')[1];
        Metadata.getInstance<Text>('statusTask').text = this.stylizeStatus(dados.IDSITUACAOAGEND);
        Metadata.getInstance<Text>('nameTask').text = dados.NMCHECKLISTAGEND;
        Metadata.getInstance<Text>('valuetime').text = time;
        Metadata.getInstance<Text>('namePlace').text = dados.NMLOCALCLIENTE;
        Metadata.getInstance<Text>('nameTypePlace').text = dados.NMLOCALPAI;
        new Promise((resolve, reject) => {
          try {
            resolve(this.statusCheck());
          } catch (error) {
            reject(error);
          }
        }).then((chk: any) => {
          if (dados.IDSITUACAOAGEND === 'Em andamento') {
            this.changeButton();
          } else if (chk) {
            Metadata.getInstance<Card>('cardButtons').isVisible = false;
          }
        });
      });
    });
  }

  public itensDetailsTask() {
    const routeParams = getRouteParams();
    const { nr } = routeParams;
    Http.post('/getItensDetailsTask', { nr }).then((response: IDictionary) => {
      response.data.dataset.cardItensDetails.forEach((dados: IDictionary) => {
        Metadata.getInstance<IterableComponentRender>('iCardDetailsTask').datasource.data.push({
          NRTAREFA: dados.NRTAREFAAGEND,
          NMTAREFA: dados.NMTAREFA,
        });
      });
    });
  }

  public stylizeStatus(status: string) {
    if (status === 'Pendente') {
      return "<span  style='background-color:#dee2e6; color: #ff6700; font-size: 10px;'>P E N D E N T E</span>";
    }
    if (status === 'Em andamento') {
      return "<span  style='background-color: #dee2e6; color: #023e8a; font-size: 11px;'>EM ANDAMENTO</span>";
    }
    if (status === 'Atrasado') {
      return "<span  style='background-color: #dee2e6; color: red; font-size: 10px;'>A T R A S A D O</span>";
    }
    return '';
  }

  public startTask() { // Iniciar tarefa na tela de detalhamento
    const routeParams = getRouteParams();
    const { nr } = routeParams;
    Http.post('/changeStatusTask', {
      button: 2,
      NRTAREFAATIVA: nr,
    }).then(() => {
      this.changeButton();
      Metadata.getInstance<Text>('statusTask').text = "<span  style='background-color: #dee2e6; color: #023e8a; font-size: 11px;'>EM ANDAMENTO</span>";
    });
  }

  public finishTask() { // Finalizar tarefa pela tela de detalhamento
    const { nr } = getRouteParams();
    const chkbox: IDictionary = [];
    Metadata.getInstance<IterableComponentRender>('iCardDetailsTask').datasource.data.forEach((dataBase: IDictionary) => {
      if (Metadata.getInstance<Checkbox>(`checkbox_${dataBase.NRTAREFA}`).value) {
        chkbox.push(dataBase.NRTAREFA);
      }
    });
    Http.post('/finishTask', {
      NRTAREFAATIVA: nr,
      CHKBOX: chkbox,
    }).then(() => {
      Router.replace('/Tarefas');
    });
  }

  public setRoute({ component }:{ component: Button }) {
    const { nr } = getRouteParams();
    component.to = `/Reportar_Tarefa/${nr}`;
  }
}
